# -*- coding: utf-8 -*-
from mootdx.reader import Reader, ExReader
from mootdx.market import LiveReader, ExLiveReader

# reader = Reader(tdxdir='')
# reader.Daily(stock=None)
# reader.ExDaily(stock=None)
# reader.MinBar(stock=None)
# reader.Custom()
# reader.Block()
